@@ -1,18 +1,21 @@
 """Module to enhance LaneletNetwork class,
 so it can be used for conversion from the opendrive format."""
 import itertools
+import logging
 import warnings
 from typing import List, Optional, Tuple
 from queue import Queue
 import numpy as np
+import shapely
+from shapely.validation import make_valid
+from pyproj import Transformer
 
 from commonroad.scenario.lanelet import LaneletNetwork, StopLine
 from commonroad.scenario.intersection import IntersectionIncomingElement, Intersection
 from commonroad.scenario.traffic_sign import TrafficLightDirection, TrafficLight, TrafficSign
 
-from crdesigner.map_conversion.osm2cr import config
-from crdesigner.map_conversion.osm2cr.converter_modules.utility import geometry
-
+from crdesigner.config.config import OpenDRIVEConversionParams
+from crdesigner.map_conversion.common import geometry
 from crdesigner.map_conversion.common.utils import convert_to_new_lanelet_id
 from crdesigner.map_conversion.common.conversion_lanelet import ConversionLanelet
 from crdesigner.map_conversion.common.utils import generate_unique_id
@@ -21,14 +24,21 @@ from crdesigner.map_conversion.common.utils import generate_unique_id
 class ConversionLaneletNetwork(LaneletNetwork):
     """
     Add functions to LaneletNetwork which further enable it to modify its Lanelets.
-    This class is being used in Opendrive and Lanelet2 format conversions
+    This class is being used in OpenDrive and Lanelet2 format conversions
     """
 
-    def __init__(self, config):
-        """Initializes a ConversionLaneletNetwork"""
+    def __init__(self, config: OpenDRIVEConversionParams = OpenDRIVEConversionParams(),
+                 transformer: Optional[Transformer] = None):
+        """
+        Initializes a ConversionLaneletNetwork
+
+        :param config: OpenDRIVE config parameters.
+        :param transformer: Coordinate projection transformer.
+        """
         super().__init__()
-        self.config = config
+        self._config = config
         self._old_lanelet_ids = {}
+        self._transformer = transformer
 
     def old_lanelet_ids(self) -> dict:
         """Get the old lanelet ids.
@@ -312,8 +322,8 @@ class ConversionLaneletNetwork(LaneletNetwork):
 
             if lanelet_join or lanelet_split:
                 js_targets.append(
-                    _JoinSplitTarget(self, lanelet, lanelet_split, lanelet_join,
-                                     self.config.precision)
+                    _JoinSplitTarget(self, lanelet, lanelet_split, lanelet_join, self._transformer,
+                                     self._config.precision)
                 )
 
         for js_target in js_targets:
@@ -690,8 +700,19 @@ class ConversionLaneletNetwork(LaneletNetwork):
                 if successor != lanelet.lanelet_id:
                     successor_lane_polygon = self.find_lanelet_by_id(successor).polygon
                     lanelet_polygon = lanelet.polygon
-                    if successor_lane_polygon.shapely_object.intersects(lanelet_polygon.shapely_object):
-                        return True
+                    if not lanelet_polygon.shapely_object.is_valid:
+                        make_valid(lanelet_polygon.shapely_object)
+                    if not successor_lane_polygon.shapely_object.is_valid:
+                        make_valid(successor_lane_polygon.shapely_object)
+                    try:
+                        if successor_lane_polygon.shapely_object.intersects(lanelet_polygon.shapely_object):
+                            return True
+                    except shapely.errors.GEOSException:
+                        logging.error("ConversionLaneletNetwork::check_if_lanelet_in_intersection: "
+                                      "Invalid lanelet shape lanelet {} or {}. "
+                                      "We assume this lanelet is not part of "
+                                      "the intersection.".format(successor, lanelet.lanelet_id))
+                        continue
         return False
 
     def check_if_successor_is_intersecting(self, intersection_map, successors_list) -> bool:
@@ -749,7 +770,7 @@ class ConversionLaneletNetwork(LaneletNetwork):
             angle = angles[index][1] - angles[prev][1]
             if angle < 0:
                 angle += 360
-            if angle > config.LANE_SEGMENT_ANGLE and angle <= 180 - config.LANE_SEGMENT_ANGLE and angle < min_angle:
+            if self._config.lane_segment_angle < angle <= 180 - self._config.lane_segment_angle and angle < min_angle:
                 # is left of the previous incoming
                 is_left_of = angles[prev][0]
                 data_index = angles[index][0]
@@ -822,7 +843,7 @@ class ConversionLaneletNetwork(LaneletNetwork):
         :return: Dict containing the directions "left", "right" or "through"
         :rtype: dict
         """
-        straight_threshold_angel = config.INTERSECTION_STRAIGHT_THRESHOLD
+        straight_threshold_angel = self._config.intersection_straight_threshold
         assert 0 < straight_threshold_angel < 90
 
         angels = {}
@@ -1110,14 +1131,19 @@ class _JoinSplitTarget:
         join/split
     """
 
-    def __init__(
-        self,
-        lanelet_network: ConversionLaneletNetwork,
-        main_lanelet: ConversionLanelet,
-        split: bool,
-        join: bool,
-        precision: float,
-    ):
+    def __init__(self,lanelet_network: ConversionLaneletNetwork, main_lanelet: ConversionLanelet, split: bool,
+                 join: bool, transformer: Optional[Transformer] = None,
+                 precision: float = OpenDRIVEConversionParams.precision):
+        """
+
+        :param lanelet_network: LaneletNetwork where join/split occurs.
+        :param main_lanelet: Lanelet where split starts or join ends.
+        :param split: Boolean indicating whether a lanelet split should be performed.
+        :param join: Boolean indicating whether a lanelet join should be performed.
+        :param transformer: Coordinate projection transformer.
+        :param precision: precision with which to convert plane group to lanelet
+        """
+
         self.main_lanelet = main_lanelet
         self.lanelet_network = lanelet_network
         if split and join:
@@ -1131,6 +1157,7 @@ class _JoinSplitTarget:
         self._js_pairs = []
         self._single_lanelet_operation = False
         self.precision = precision
+        self._transformer = transformer
 
     @property
     def split(self) -> bool:
@@ -1265,7 +1292,7 @@ class _JoinSplitTarget:
                 [0, length],
                 [width_start, width_end],
             )
-            js_pair.move_border(width=distance, linking_side=self.linking_side)
+            js_pair.move_border(width=distance, linking_side=self.linking_side, transformer=self._transformer)
             running_pos += pos_end - pos_start
 
     def _move_borders_if_split_and_join(self):
@@ -1492,21 +1519,21 @@ class _JoinSplitTarget:
 class _JoinSplitPair:
     """Pair of lanelet whose border is changed and its adjacent neighbor."""
 
-    def __init__(self, lanelet, adjacent_lanelet, change_interval, precision):
+    def __init__(self, lanelet, adjacent_lanelet, change_interval,
+                 precision: float = OpenDRIVEConversionParams.precision):
         self.lanelet = lanelet
         self.adjacent_lanelet = adjacent_lanelet
         self.change_interval = change_interval
         self.precision = precision
 
-    def move_border(self, width: np.ndarray, linking_side: str) -> ConversionLanelet:
+    def move_border(self, width: np.ndarray, linking_side: str,
+                    transformer: Optional[Transformer] = None) -> ConversionLanelet:
         """Move border of self.lanelet.
 
         :param width: Start and end value of new width of lanelet.
-        :type width: np.ndarray
         :param linking_side: Side on which the split/join happens, either "left" or "right"
-        :type linking_side: str
+        :param transformer: Coordinate projection transformer.
         :return: Resulting lanelet after border movement.
-        :rtype: :class:`ConversionLanelet`
         """
         self.lanelet.move_border(
             mirror_border=linking_side,
@@ -1514,5 +1541,6 @@ class _JoinSplitPair:
             distance=width,
             adjacent_lanelet=self.adjacent_lanelet,
             precision=self.precision,
+            transformer=transformer
         )
         return self.lanelet
