@@ -7,7 +7,7 @@ from crdesigner.ui.gui.mwindow.toolboxes.service_layer.general_services import t
 def create_converter_toolbox(mwindow):
     """ Create the map converter toolbar_wrapper."""
     mwindow.map_converter_toolbox = MapConversionToolbox(mwindow.animated_viewer_wrapper.cr_viewer.current_scenario,
-                                                         lambda scenario: toolbox_callback(mwindow, scenario),
+                                                         lambda scenario: toolbox_callback(mwindow, scenario, True),
                                                          mwindow.crdesigner_console_wrapper.text_browser,
                                                          mwindow.obstacle_toolbox.sumo_simulation, mwindow)
     mwindow.addDockWidget(Qt.RightDockWidgetArea, mwindow.map_converter_toolbox)
